@@ -48,6 +48,7 @@ struct BuilderSourceArchive
   gboolean      git_init;
   char         *archive_type;
   char         *http_referer;
+  gboolean      disable_http_decompression;
 };
 
 typedef struct
@@ -71,6 +72,7 @@ enum {
   PROP_GIT_INIT,
   PROP_ARCHIVE_TYPE,
   PROP_HTTP_REFERER,
+  PROP_DISABLE_HTTP_DECOMPRESSION,
   LAST_PROP
 };
 
@@ -208,6 +210,10 @@ builder_source_archive_get_property (GObject    *object,
       g_value_set_string (value, self->http_referer);
       break;
 
+    case PROP_DISABLE_HTTP_DECOMPRESSION:
+      g_value_set_boolean (value, self->disable_http_decompression);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -295,6 +301,10 @@ builder_source_archive_set_property (GObject      *object,
       self->http_referer = g_value_dup_string (value);
       break;
 
+    case PROP_DISABLE_HTTP_DECOMPRESSION:
+      self->disable_http_decompression = g_value_get_boolean (value);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -466,6 +476,7 @@ builder_source_archive_download (BuilderSource  *source,
                                      self->url,
                                      (const char **)self->mirror_urls,
                                      self->http_referer,
+                                     self->disable_http_decompression,
                                      file,
                                      checksums,
                                      checksums_type,
@@ -1008,6 +1019,14 @@ builder_source_archive_class_init (BuilderSourceArchiveClass *klass)
                                                         "",
                                                         NULL,
                                                         G_PARAM_READWRITE));
+
+  g_object_class_install_property (object_class,
+                                   PROP_DISABLE_HTTP_DECOMPRESSION,
+                                   g_param_spec_boolean ("disable-http-decompression",
+                                                        "",
+                                                        "",
+                                                        FALSE,
+                                                        G_PARAM_READWRITE));
 }
 
 static void
